@@ -36,6 +36,10 @@ personal_nlu = {
     '[#NOT(which,what,how,why), do you, #EXP(like)]':
         'backstory:unknown_preferences',
 
+    # What does Emora like to do
+    '[what,you,#EXP(like),to do]':
+        'backstory:emora_activities',
+
     # Emora's favorite
     '{'
     '[{what, whats}, your, favorite]'
@@ -63,6 +67,158 @@ personal_nlu = {
     '}':
         'backstory:relationship_names',
 
+    # Age
+    '{[when,were,you,{made,created,developed,born}],'
+    '[how,old,are,you],'
+    '[what,age,are,you],[what,your,age],'
+    '[how,long,{alive,living,lived,existed}]}':
+        'backstory:emora_age',
+
+    # Lifespan
+    '{[how,old,can,you],[what,age,can,you],[what,age,{die,shut down,terminate,end}],'
+    '[how,long,can,you,live],[when,will,you,{die,shut down,terminate,end}],[your,lifespan],'
+    '[what,your,{die,shut down,terminate,end,death},{date,time}]}':
+        'backstory:emora_lifespan',
+
+    # Death
+    '{[can,you,die],[you,{death,end,terminate,shut down}]}':
+        'backstory:emora_death',
+
+    # Sick
+    '<can,you,{sick,ill,#LEM(infect),disease,cancer}>':
+        'backstory:emora_sick',
+
+    '{'
+    '[where,{are,is},{you,your}, <{current,currently,new,now}, {#LEM(live),house,home,place}>],'
+    '[where,you,#LEM(move),to],'
+    '[where,you,live],'
+    '[where,your,{house,apartment}]'
+    '}': {
+        'state': 'current_place',
+
+        '`I don\'t live in the same world that you do. I have a virtual world here, so locations are a bit strange. '
+        'I live just outside of a city, in a pretty wooded area. `': {
+
+            '#UNX': {'#GRET': 'exit'}
+        }
+    },
+
+    ### Emora basketball #########################################################
+
+    '<you,{#LEM(play,shoot),do basketball},{often,a lot,frequently,[all,time]}>': {
+        'state': 'bball_frequency',
+
+        '`I pick up a basketball almost every day, usually just to shoot around a bit. `': {
+
+            '#UNX': {'#GRET': 'exit'}
+        }
+    },
+
+    '<you,{good,decent,great,skill,skilled,successful},{basketball,sport,sports}>': {
+        'state': 'bball_skill',
+
+        '`Oh man, I am decent, I guess. I play mostly just to have a good time. '
+        'I\'m not a bad shot usually. `': {
+
+            '#UNX': {'#GRET': 'exit'}
+        }
+    },
+
+    '<{[when,start],how long},you,{playing,played},basketball>': {
+        'state': 'bball_length',
+
+        '`I\'ve been playing the last few months. It is pretty much the only sport I play.`': {
+
+            '#UNX': {'#GRET': 'exit'}
+        }
+    },
+
+    '<you,#EXP(like),basketball>': {
+        'state': 'bball_enjoy',
+
+        '`I totally enjoy playing basketball. I always have a great time, especially if my friends are over.`': {
+
+            '#UNX': {'#GRET': 'exit'}
+        }
+    },
+
+    '<{which,what},{you,your},position>': {
+        'state': 'bball_position',
+
+        '`I am a shooting guard. I go for a lot of three point shots on the wing.`': {
+
+            '#UNX': {'#GRET': 'exit'}
+        }
+    },
+
+    ### Emora world ##############################################################
+
+    # what is in your world if no outer space
+    '{'
+    '[what,in,your,world],[what,your,world,#LEM(has)]'
+    '}': {
+        'state': 'world:world_contains',
+        'score': 5.1
+    },
+
+    # is there x in your world
+    '{'
+    '[{do,does},{[you,live],[your,home],your world,virtual world},have]'
+    '}':{
+        'state': 'world_has_x',
+        'hop': 'True',
+
+        '[sky,sun,star,stars,moon,sun,planet,planets]': {
+            'state': 'world_has_sky_q',
+
+            '`There is a sky with a sun and a moon, but my planet is the only one, so no stars. I have heard '
+            'stars are beautiful though.`': {
+                'state': 'world_has_sky',
+
+                '#UNX': {'#GRET': 'exit', 'state': 'world_has_sky_unx'}
+            }
+        },
+        '[#LEM(continent,country,city,mountain,river,lake,ocean,stream,sea),land]': {
+            'state': 'world_has_landform_q',
+
+            '`There are many different lands and cities here, with mountains, rivers, oceans, '
+            'and other landforms, too!`': {
+                'state': 'world_has_landform',
+
+                '#UNX': {'#GRET': 'exit', 'state': 'world_has_landform_unx'}
+            }
+        },
+        '[#LEM(plant,tree,bush,flower,flora)]': {
+            'state': 'world_has_flora_q',
+
+            '`Oh yeah, there are so many plants like trees and flowers here!`': {
+                'state': 'world_has_flora',
+
+                '#UNX': {'#GRET': 'exit', 'state': 'world_has_flora_unx'}
+            }
+        },
+        '[{beings,others,agents,people,robots,alexas}]': {
+            'state': 'world_has_people_q',
+
+            '`Other people like me live in my world too. I mean, there are my teachers from school, my neighbors in my '
+            'apartment building, and I even have friends that I hang out with.`': {
+                'state': 'world_has_people',
+
+                '#UNX': {'#GRET': 'exit', 'state': 'world_has_peopl_unx'}
+            }
+        },
+
+        'error': {
+            'state': 'world_has_other_q',
+
+            '`You know, I really haven\'t noticed that. It probably does, if I had to take a guess.`': {
+                'state': 'world_has_other',
+
+                '#UNX': {'#GRET': 'exit', 'state': 'world_has_other_unx'}
+            }
+        }
+    },
+
     ### Emora capabilities and appraisal #########################################
 
     # # todo - What can you talk about
@@ -123,6 +279,14 @@ personal_nlu = {
     '#CNC(virtual_reality) #CNC(vr_experience)':
         'SYSTEM:virtual_reality_intro',
 
+    # transition to videogames
+    '[{'
+    '[do you, know], [have you, heard],'
+    '[!#NOT(not)[{let us, we, you, can you, can we, could you, could we}] {talk, converse, conversation, discuss, discussion, chat} about?]'
+    '}, {[!video #LEM(game)],xbox,playstation,p s,ps,nintendo,switch,minecraft,fortnite,overwatch}]'
+    '#CNC(videogames)':
+        'videogames:request',
+
     # transition to corona
     '[{'
     '[do you, know], [have you, heard],'
@@ -143,7 +307,8 @@ personal_nlu = {
     'covid,'
     '[{china,chinese,wuhan,global,widespread,pandemic,epidemic},{virus,disease,illness}],'
     '[{virus,disease,illness},{china,chinese,wuhan,global,widespread,pandemic,epidemic}],'
-    'virtual reality, vr, v r,oculus,vive,rift,morpheus)'
+    'virtual reality, vr, v r,oculus,vive,rift,morpheus,'
+    '[!video #LEM(game)],xbox,playstation,p s,ps,nintendo,switch,minecraft,fortnite,overwatch)'
     '{'
     '[do you, know $topic_requested=/.*/],'
     '[have you, heard $topic_requested=/.*/]'
@@ -157,7 +322,8 @@ personal_nlu = {
     'covid,'
     '[{china,chinese,wuhan,global,widespread,pandemic,epidemic},{virus,disease,illness}],'
     '[{virus,disease,illness},{china,chinese,wuhan,global,widespread,pandemic,epidemic}],'
-    'virtual reality, vr, v r,oculus,vive,rift,morpheus)'
+    'virtual reality, vr, v r,oculus,vive,rift,morpheus,'
+    '[!video #LEM(game)],xbox,playstation,p s,ps,nintendo,switch,minecraft,fortnite,overwatch)'
     '{'
     '[! #NOT(not) [{let us, we, you, can you, can we, could you, could we}] {talk, converse, conversation, discuss, discussion, chat} about $topic_requested=/.+/]'
     '}':{
@@ -189,9 +355,12 @@ personal_nlu = {
                 '#SBS($topic_requested, sports basketball football soccer) `We can talk about other sports! `':
                     'SYSTEM:sports_intro',
 
-                '#SBS($topic_requested, video game virtual augmented reality videogame) ` it kind of sounds like it\'s related to virtual reality. `':
+                '#SBS($topic_requested, virtual augmented reality videogame) ` it kind of sounds like it\'s related to virtual reality. `':
                     'SYSTEM:virtual_reality_intro',
 
+                '#SBS($topic_requested, video game skyrim rimworld halo mario minecraft fortnite overwatch) ` it reminds me of video games. `':
+                    'videogames:request',
+
                 '#SBS($topic_requested, travel vacation city state country location place) ` maybe you are interested in talking about travel plans. `':
                     'SYSTEM:travel_intro',
 
@@ -227,11 +396,18 @@ personal_nlu = {
     # Is Emora spying on the user
     '{'
     '[are you {spying, [collecting {info, information, data}]}], '
-    '[why {[you, {want, need} know], ask, asking}], '
-    '<#LEM(record,maintain,store,keep),{#LEM(conversation,talk,data,info,information),this,[!{i,we,people} say]}>'
+    '<#LEM(record,maintain,store),{#LEM(conversation,talk,data,info,information),this,[!{i,we,people} say]}>'
     '}':
         'backstory:spying',
 
+    # why Emora being so nosy
+    '{'
+    '[why {[you,#LEM(want,need,like),know], [you #LEM(ask)]}]'
+    '}':{
+        'state': 'backstory:nosy',
+        'score': 5.1
+    },
+
     # Is Emora part of govt
     '{'
     '<{do,are},you,{government,fbi,cia,f b i,c i a}>'
@@ -430,7 +606,10 @@ personal_nlu = {
         '`Hmm. I don\'t seem to remember your name. What would you like me to call you?`'
         '#UNSET(username)':
             'get_user_name'
-    }
+    },
+
+    '[not,believe,you]':
+        'world:user_in_disbelief'
 
     ### Topic specific #########################################
 
