@@ -5,15 +5,15 @@ from emora_stdm import DialogueFlow
 house = DialogueFlow('_local_start')
 house.knowledge_base().load_json_file(PATHDIR.replace('__***__','_common.json'))
 house.knowledge_base().load_json_file(PATHDIR.replace('__***__','house.json'))
-house.add_system_transition('_local_start', 'start', '')
+house.add_system_transition('_local_start', 'start', '#RAND(life_in,True)')
 
 
 system = {
     'state': 'start',
-    'enter': '#GATE #GCOM(house) #GOAL(house)',
+    'enter': '#GATE #GCOM(house) #GOAL(house) #IF($life_in=True) #ANY($is_student=False,$is_student=None)',
 
-    '`Oh my gosh, I had a wonderful day yesterday! My friends came over to my new apartment for the first time and '
-    'it was totally perfect.`'
+    '`Do you want to know something? I can\'t stop thinking about how good my day was yesterday. '
+    'My friends came over to my new apartment for the first time and it was so much fun.`'
     '#GSRET(user_living) #SET($introduced_virtual=False)':{
         'state': 'share_new_house',
         'score': 2.0,
@@ -24,7 +24,16 @@ system = {
             '`Yeah I really like it, it\'s close to where I go to school and it even has a community basketball court.`'
             '#GSRET(user_living)':{
 
-                '[you,{school,student}]': 'school_new:start',
+                '[you,{school,student}]': {
+
+                    '`Oh yeah, I am a student right now and go to school. `':{
+                        'state': 'school_new:start',
+                        'score': 2.0
+                    },
+
+                    '`Oh yeah, I am a student right now and go to school.  `':
+                        'user_living'
+                },
 
                 '[you,basketball]': {
                     'state': 'community_bball',
@@ -49,10 +58,10 @@ system = {
             }
         },
 
-        '#TOKLIMIT(3)': {
-            'state': 'world:user_in_disbelief',
-            'score': 0.9
-        },
+        # '#TOKLIMIT(3)': {
+        #     'state': 'world:user_in_disbelief',
+        #     'score': 0.9
+        # },
 
         '#UNX': {
             'state': 'user_living'
@@ -181,7 +190,8 @@ user_living = {
                 '#IDK': {
                     'state': 'user_hates_house_idk',
 
-                    '`Oh dear, well I hope it isn\'t too bad. Is it at least close to where you work? `':
+                    '`Oh dear, well I hope it isn\'t too bad. Is it at least close to where you work? `'
+                    '#GSRET(school_proximity)':
                         'asked_school_proximity'
                 },
 
@@ -293,35 +303,59 @@ user_living = {
 school_proximity = {
     'state': 'school_proximity',
 
+    '#IF($is_employed=False)': {
+        'score': 1.1,
+        'state': 'live_with'
+    },
+
     '`So are you close to where you work?`'
     '#GSRET(exit)': {
         'state': 'asked_school_proximity',
 
+        '{[unemployed],[#NEGATION,{work,job,employed}],[!a {kid,child}]}'
+        '#SET($is_employed=False)':{
+            'state': 'not_work',
+
+            '`Oh, sorry, I didn\'t know that. Well, I hope you are close to places you like to '
+            'go to a lot. `': 'old_apartment_distance'
+        },
+
         '{#AGREE, [!-#NEGATION [i am, close]], [not far]}'
-        '#SET($has_job=True)': {
+        '#SET($is_employed=True)': {
 
             '`That\'s really good.`': {
                 'state': 'old_apartment_distance',
                 'hop': 'True',
 
-                '`My old apartment was forty five minutes away from where I go to school, it was the worst.`': {
+                '`My old apartment was forty five minutes away from where I go to school, it was the worst.`'
+                '#GSRET(live_with)': {
 
                     '[{fifty, hour, eighty, ninety}]': {
 
-                        '`Wow how did you even survive?`': {
+                        '`Wow how do you even survive?`': {
 
                             '#UNX': 'live_with'
                         }
                     },
 
-                    '[you,{school,student}]': 'school_new:start',
+                    '[you,{school,student}]': {
+
+                        '`Yes, I am a student right now and go to school. `':{
+                            'state': 'school_new:start',
+                            'score': 2.0
+                        },
+
+                        '`Yes, I am a student right now and go to school.  `':
+                            'live_with'
+                    },
 
                     '#UNX': 'live_with'
                 }
             }
         },
 
-        '{#DISAGREE, [i, am, not], [not, close]}': {
+        '{#DISAGREE, [i, am, not], [not, close]}'
+        '#SET($is_employed=True)': {
 
             '`Oh I hate that.`': 'old_apartment_distance'
         },
@@ -333,6 +367,8 @@ school_proximity = {
 entertain_people = {
     'state': 'ask_entertain_people',
 
+    '#DEFAULT `So, do you like having people over at your place?`': 'asked_entertain_people',
+
     '`Now that I have a bigger apartment, I think I will enjoy hosting more gatherings. Do you like having people over '
     'at your place?`'
     '#GATE': {
@@ -349,7 +385,7 @@ entertain_people = {
             }
         },
 
-        '[{#DISAGREE, i do not, #ONT(_negative adj)}]'
+        '[{#DISAGREE, not so much, i do not, #ONT(_negative adj)}]'
         '#SET($user_likes_hosting=False)': {
             'state': 'hates_hosting',
 
@@ -361,24 +397,35 @@ entertain_people = {
             }
         },
 
+        '[{coronavirus,corona,pandemic,#LEM(isolate,distance,quarantine),'
+        'shelter in place,stay at home,lockdown,[!social #LEM(distance)]}]': {
+            'state': 'hosting_coronavirus_restrictions',
+            'score': 10.1,
+
+            '`I am really sorry to hear that. Hopefully you can get together with the people you care about soon.`'
+            '#GSRET(school_proximity)': {
+
+                '#UNX': 'school_proximity'
+            }
+        },
+
         '#UNX':{
             'state': 'unx_hosting',
 
-            '`It can be a lot of work, but it is nice to bring everyone toether! Although, if someone else '
-            'hosts, we don\'t have to worry about all the details. So many things to consider.`'
+            '`It can be a lot of work, but it is nice to bring everyone together! `'
             '#GSRET(school_proximity)': {
 
                 '#UNX': 'school_proximity'
             }
         }
-    },
-
-    '#DEFAULT `So, do you like having people over at your place?`': 'asked_entertain_people'
+    }
 }
 
 live_with = {
     'state': 'live_with',
 
+    '#DEFAULT `Wait, do you live with anyone?`': 'live_with_response',
+
     '`You know, sometimes I can get lonely because I don\'t have any roommates, '
     'even though I do have friends and family come over a lot. Do you live with anyone?`'
     '#GATE': {
@@ -386,14 +433,17 @@ live_with = {
 
         '[#EXTR(lives_with, _related person)]':{
             'state': 'lives_with_fam',
+            'score': 1.1,
 
-            '`That\'s nice! Do you guys get along well?`': {
+            '`That\'s nice! Do you guys get along well?`'
+            '#GSRET(exit)': {
                 'state': 'ask_get_along',
 
                 '[#NOT(not) {#AGREE, we do, mostly, most, usually, a lot}]':{
                     'state': 'get_along_yes',
 
-                    '`That\'s really good to hear. You seem like a pretty grateful person.`': {
+                    '`That\'s really good to hear. You seem like a pretty grateful person.`'
+                    '#GSRET(exit)': {
                         'state': 'get_along_yes_unx',
 
                         '#UNX': 'exit'
@@ -404,7 +454,8 @@ live_with = {
                     'state': 'get_along_no',
 
                     '`Oh, it must be pretty stressful to live with people you don\'t have a good relationship '
-                    'with. I\'m sorry. `': {
+                    'with. I\'m sorry. `'
+                    '#GSRET(exit)': {
                         'state': 'get_along_no_unx',
 
                         '#UNX': 'exit'
@@ -419,6 +470,13 @@ live_with = {
             }
         },
 
+        '#AGREE #GATE':{
+            'state': 'lives_with_y',
+
+            '`Oh, that\'s cool! Who do you live with then?`': 'live_with_response'
+
+        },
+
         '[{#DISAGREE, alone, myself, no one, nobody, anybody, me too, neither, either, i do not, have not}]'
         '#SET($user_lives_alone=True)':{
             'score': 0.9,
@@ -435,7 +493,7 @@ live_with = {
                 '#DISAGREE':{
                     'state': 'hates_lives_alone',
 
-                    '`I understand that.`': 'exit'
+                    '`I understand that. It can be kind of boring.`': 'exit'
                 },
 
                 '#UNX': 'exit'
@@ -443,15 +501,13 @@ live_with = {
         },
 
         '#UNX(Okay. )': 'exit'
-    },
-
-    '#DEFAULT `Wait, do you live with anyone?`': 'live_with_response'
+    }
 }
 
 exit = {
     'state': 'exit',
 
-    '#GCOM(house)': {
+    '#GCOM(house) #GRET': {
         'score': 0.0,
         'state':'SYSTEM:root'
     }
@@ -469,16 +525,6 @@ user = {
         }
     },
 
-    '{[where,{are,is},{you,your}, <{current,currently,new,now}, {#LEM(live),house,home,place}>],[where,#LEM(move),to]}':{
-        'state': 'current_place',
-
-        '`I don\'t live in the same world that you do. I have a virtual world here, so locations are a bit strange. '
-        'I live just outside of a city, in a pretty wooded area. `': {
-
-            '#UNX': {'#GRET': 'exit'}
-        }
-    },
-
     '<you,#EXP(like),{old,previous,past,last,used,before},{#LEM(live),house,home,place}>': {
         'state': 'like_previous_place',
 
@@ -495,51 +541,17 @@ user = {
         '`Thanks! ` #GRET': 'exit'
     },
 
-    '<you,{#LEM(play,shoot),do basketball},{often,a lot,frequently,[all,time]}>': {
-        'state': 'bball_frequency',
+    '[{covid,coronavirus,corona,pandemic,#LEM(isolate,distance,quarantine),'
+    'shelter in place,stay at home,lockdown,[!social #LEM(distance)]}]': {
+        'state': 'coronavirus_restrictions',
 
-        '`I pick up a basketball almost every day, usually just to shoot around a bit. `': {
-
-            '#UNX': {'#GRET': 'exit'}
-        }
-    },
-
-    '<you,{good,decent,great,skill,skilled,successful},{basketball,sport,sports}>': {
-        'state': 'bball_skill',
-
-        '`Oh man, I am decent, I guess. I play mostly just to have a good time. '
-        'I\'m not a bad shot usually. `': {
-
-            '#UNX': {'#GRET': 'exit'}
-        }
-    },
-
-    '<how long,you,{playing,played}>': {
-        'state': 'bball_length',
-
-        '`For the last few months. It is pretty much the only sport I play.`': {
-
-            '#UNX': {'#GRET': 'exit'}
-        }
-    },
-
-    '<you,#EXP(like),basketball>': {
-        'state': 'bball_enjoy',
-
-        '`I totally enjoy playing basketball. I always have a great time, especially if my friends are over.`': {
-
-            '#UNX': {'#GRET': 'exit'}
-        }
-    },
-
-    '<{you,your},position>': {
-        'state': 'bball_position',
-
-        '`I am a shooting guard. I go for a lot of three point shots on the wing.`': {
+        '`The coronavirus doesn\'t affect me where I live, since it is separate from your physical world. I am really '
+        'sorry to hear that you have so many restrictions on you. I hope you are staying safe and healthy.`': {
 
             '#UNX': {'#GRET': 'exit'}
         }
     }
+
 }
 
 update_rules = {
@@ -555,9 +567,9 @@ house.load_transitions(live_with)
 house.load_transitions(school_proximity)
 house.load_transitions(entertain_people)
 house.load_transitions(exit)
-house.load_global_nlu(user, default_score=1.01)
+house.load_global_nlu(user, default_score=10.0)
 house.load_update_rules(update_rules)
 
 if __name__ == '__main__':
-    house.precache_transitions()
+    #house.precache_transitions()
     house.run(debugging=True)
\ No newline at end of file
