@@ -842,95 +842,88 @@ class ExpandContractions(Macro):
 
     def __init__(self):
         contractions = {
-            "ain't": "is not",
-            "aren't": "are not",
-            "cannot": "can not",
-            "can't": "can not",
-            "can't've": "can not have",
-            "'cause": "because",
-            "could've": "could have",
-            "couldn't": "could not",
-            "couldn't've": "could not have",
-            "didn't": "did not",
-            "doesn't": "does not",
-            "don't": "do not",
-            "hadn't": "had not",
-            "hasn't": "has not",
-            "haven't": "have not",
-            "he'd": "he would",
-            "he'd've": "he would have",
-            "he'll": "he will",
-            "he's": "he is",
-            "how'd": "how did",
-            "how'll": "how will",
-            "how's": "how is",
-            "I'd": "I would",
-            "I'd've": "I would have",
-            "I'll": "I will",
-            "I'll've": "I will have",
-            "I'm": "I am",
-            "I've": "I have",
-            "isn't": "is not",
-            "it'd": "it would",
-            "it'll": "it will",
-            "it's": "it is",
-            "let's": "let us",
-            "might've": "might have",
-            "must've": "must have",
-            "mustn't": "must not",
-            "she'd": "she would",
-            "she'll": "she will",
-            "she's": "she is",
-            "should've": "should have",
-            "shouldn't": "should not",
-            "shouldn't've": "should not have",
-            "so's": "so is",
-            "that's": "that is",
-            "there'd": "there would",
-            "there'd've": "there would have",
-            "there's": "there is",
-            "they'd": "they would",
-            "they'll": "they will",
-            "they're": "they are",
-            "they've": "they have",
-            "wanna": "want to",
-            "wasn't": "was not",
-            "we'd": "we would",
-            "we'd've": "we would have",
-            "we'll": "we will",
-            "we're": "we are",
-            "we've": "we have",
-            "weren't": "were not",
-            "what'll": "what will",
-            "what're": "what are",
-            "what's": "what is",
-            "what've": "what have",
-            "when's": "when is",
-            "when've": "when have",
-            "where'd": "where did",
-            "where's": "where is",
-            "where've": "where have",
-            "who'll": "who will",
-            "who'll've": "who will have",
-            "who's": "who is",
-            "who've": "who have",
-            "why's": "why is",
-            "why've": "why have",
-            "will've": "will have",
-            "won't": "will not",
-            "won't've": "will not have",
-            "would've": "would have",
-            "wouldn't": "would not",
-            "wouldn't've": "would not have",
-            "y'all": "you all",
-            "y'all're": "you all are",
-            "y'all've": "you all have",
-            "you'd": "you would",
-            "you'd've": "you would have",
-            "you'll": "you will",
-            "you'll've": "you will have",
-            "you're": "you are",
-            "you've": "you have"
+            "aint": "is not",
+            "arent": "are not",
+            "cant": "can not",
+            "cantve": "can not have",
+            "cause": "because",
+            "couldve": "could have",
+            "couldnt": "could not",
+            "couldntve": "could not have",
+            "didnt": "did not",
+            "doesnt": "does not",
+            "dont": "do not",
+            "hadnt": "had not",
+            "hasnt": "has not",
+            "havent": "have not",
+            "hed": "he would",
+            "hedve": "he would have",
+            "hes": "he is",
+            "howd": "how did",
+            "howll": "how will",
+            "hows": "how is",
+            "idve": "I would have",
+            "illve": "I will have",
+            "im": "I am",
+            "ive": "I have",
+            "isnt": "is not",
+            "itd": "it would",
+            "itll": "it will",
+            "its": "it is",
+            "lets": "let us",
+            "mightve": "might have",
+            "mustve": "must have",
+            "mustnt": "must not",
+            "shed": "she would",
+            "shell": "she will",
+            "shes": "she is",
+            "shouldve": "should have",
+            "shouldnt": "should not",
+            "shouldntve": "should not have",
+            "sos": "so is",
+            "thats": "that is",
+            "thered": "there would",
+            "theredve": "there would have",
+            "theres": "there is",
+            "theyd": "they would",
+            "theyll": "they will",
+            "theyre": "they are",
+            "theyve": "they have",
+            "wasnt": "was not",
+            "wed": "we would",
+            "wedve": "we would have",
+            "weve": "we have",
+            "werent": "were not",
+            "whatll": "what will",
+            "whatre": "what are",
+            "whats": "what is",
+            "whatve": "what have",
+            "whens": "when is",
+            "whenve": "when have",
+            "whered": "where did",
+            "wheres": "where is",
+            "whereve": "where have",
+            "wholl": "who will",
+            "whollve": "who will have",
+            "whos": "who is",
+            "whove": "who have",
+            "whys": "why is",
+            "whyve": "why have",
+            "willve": "will have",
+            "wont": "will not",
+            "wontve": "will not have",
+            "wouldve": "would have",
+            "wouldnt": "would not",
+            "wouldntve": "would not have",
+            "yall": "you all",
+            "yallre": "you all are",
+            "yallve": "you all have",
+            "youd": "you would",
+            "youdve": "you would have",
+            "youll": "you will",
+            "youllve": "you will have",
+            "youre": "you are",
+            "youve": "you have"
         }
         self.contractions = {''.join([a.lower() for a in k if a.isalpha() or a == ' ']): v.lower() for k, v in contractions.items()}
         self.re = r'\b(?:{})\b'.format('|'.join(self.contractions.keys()))
