@@ -81,19 +81,30 @@ interested = '{[!-not [{great, good, cool, awesome, nice, sweet, wonderful, amaz
              'wow, my god, woah, interesting, oh}]], really}'
 Interested = CommonNatexMacro(interested)
 
+decline_share = "{" \
+                "[not, #LEM(talk,discuss,share,give,tell,say)]," \
+                "[none,your,business]," \
+                "[that is private]" \
+                "}"
+DeclineShare = CommonNatexMacro(decline_share)
+
 class Unexpected(Macro):
 
     def __init__(self):
         self.question_natex = NatexNLU(question)
 
     def run(self, ngrams: Ngrams, vars: Dict[str, Any], args: List[Any]):
+        statement_only = 's' in args or 'state' in args or 'statement' in args
         vars['__score__'] = 0.0
         if '__previous_unx_response__' not in vars:
             vars['__previous_unx_response__'] = 'Gotcha.'
         if '__previous_unx_answer__' not in vars:
             vars['__previous_unx_answer__'] = 'None'
 
-        if self.question_natex.match(ngrams.text()):
+        is_question = self.question_natex.match(ngrams.text())
+        if is_question and statement_only:
+            return False
+        elif self.question_natex.match(ngrams.text()):
             if '_explained_stupidity_' in vars and vars['_explained_stupidity_'] == 'True':
                 options = {'I\'m not sure.', 'I don\'t know.', 'I\'m not sure about that.', ''} - {
                     vars['__previous_unx_response__']}
@@ -104,14 +115,14 @@ class Unexpected(Macro):
                 vars['_explained_stupidity_'] = 'True'
                 vars['__response_prefix__'] = 'Sorry, I don\'t think I understand your question. ' \
                                               'There\'s still a lot I\'m trying to figure out. '
-        elif len(ngrams.text().split()) < 3:
+        elif len(ngrams.text().split()) < 2:
             vars['__response_prefix__'] = ''
             return True
         else:
             options = {'Yeah.', 'For sure.', 'Right.', 'Uh-huh.'} - {vars['__previous_unx_response__']}
             statement_response = random.choice(list(options))
             if len(args) > 0:
-                statement_response = ', '.join(args)
+                statement_response = ', '.join([arg for arg in args if arg not in {'s', 'state', 'statement'}])
                 if args[0] == 'None':
                     statement_response = ''
             vars['__previous_unx_response__'] = statement_response
@@ -130,6 +141,7 @@ natex_macros_common = {
     'NOTINTERESTED': NotInterested(),
     'INTERESTED': Interested(),
     'UNX': Unexpected(),
+    'PRIVATE': DeclineShare()
 }
 
 if __name__ == '__main__':
